#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store
version:              0.7.20
visibility:           public
id:                   store-0.7.20-9yzG4EeiDjW6EDX4aYt7k8
key:                  store-0.7.20-9yzG4EeiDjW6EDX4aYt7k8
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/mgsloan/store#readme
synopsis:             Fast binary serialization
category:             Serialization, Data
abi:                  b853326172020033b04716635b5bf105
exposed:              True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer

hidden-modules:       Data.Store.Impl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-0.7.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store
hs-libraries:         HSstore-0.7.20-9yzG4EeiDjW6EDX4aYt7k8
depends:
    array-0.5.6.0 async-2.2.6-Gml4H6UctygFSqCTsp1iZf base-4.18.2.1
    base-orphans-0.9.3-4aYU8kUnH3JJ5hhvXSRw2I
    base64-bytestring-1.2.1.0-6zbb0o9xH9hLkYSzTxgmy9
    bifunctors-5.6.3-YxSBUqUlPdGZQ9m4yv66V bytestring-0.11.5.3
    containers-0.6.7 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha1-0.11.101.0-Dr7tkgtlkwAD12N9xZyl0y deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    free-5.2-Er0CxsHDrKnLj21y4IHBVi ghc-prim-0.10.0
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    hspec-2.11.5-9jOU1kYubwn2Hm3KxBN8g5
    hspec-smallcheck-0.5.3-9jolTAz9SHkByYF2VEib1O integer-gmp-1.1
    lifted-base-0.2.3.12-WXjI17rAo31Gl6dzILdp1
    monad-control-1.0.3.1-2dUcvCkYfVy8ju8FJuDKvv
    mono-traversable-1.0.21.0-CeXYeFW75pW28gCGqOjYKl
    network-3.1.4.0-57XjnahcYfrBnbtgCzAhJP
    primitive-0.9.1.0-2IRhja9DqVYHGJwyknHO82
    resourcet-1.2.6-GrVaNPG3RF7IMcvlKlmJk8
    safe-0.3.21-9fS1HagXWSs3bwv9EfXX3u
    smallcheck-1.2.1.1-7J3brsb76wp3kckAjkhPcO
    store-core-0.4.4.7-IDkrBzosplPD9iZemSqVQC
    syb-0.7.3-GhxEKVO9aRZHddME5iK0hL template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-259dLbfPJk9HrfYIeZHdvQ
    th-lift-instances-0.1.20-FVACtvKHKUXJEGN8xv22ay
    th-orphans-0.13.17-KpFDsHyqo6QII5eH3GsfCa
    th-reify-many-0.1.10-KrVi6XMY6V2BZJwSzCMnCd
    th-utilities-0.2.5.2-EzkltwfzqexCxk8NhWA93m time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-store/html/store.haddock
haddock-html:         /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

